@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.14.1+1-LTS" },
-            { "jdk", "11.0.14.1" },
-            { "release", "11.0.14.1" },
+            { "full", "11.0.26+4-LTS" },
+            { "jdk", "11.0.26" },
+            { "release", "11.0.26" },
         };
     }
 }
